gtoolz.Spinner

# ``gtoolz`.`Spinner``

class documentation

`class Spinner:`

View In Hierarchy

purpose: prints a spinner in place input: msg="": str style='bar': ellipsis, pipe, box, vbar, growing_bar, missing_box, solid_box, arrow, clock, bar, balloons, moon, dot, braille, pulse prog|progressive|progress: bool color: str txt_color: str elspsed: bool requires: import sys import threading import itertools return: none use: with Spinner("Working...", style='bar') long_proc() with Spinner("Doing long work...", style='vbar', progressive=True, colors=shades('red')) for x in range(100): time. sleep(1)

Method | `__enter__` | Undocumented
Method | `__exit__` | Undocumented
Method | `__init__` | --== debugging ==--
Method | `spin_backover` | Undocumented
Method | `spin_proc` | Undocumented
Method | `write_next` | Undocumented
Instance Variable | `busy` | Undocumented
Instance Variable | `centered` | Undocumented
Instance Variable | `chr_cnt` | Undocumented
Instance Variable | `clr_cnt` | Undocumented
Instance Variable | `color` | Undocumented
Instance Variable | `COLOR` | Undocumented
Instance Variable | `colors` | --== SEP_LINE ==--
Instance Variable | `delay` | Undocumented
Instance Variable | `elapsed` | Undocumented
Instance Variable | `etime` | Undocumented
Instance Variable | `prog` | Undocumented
Instance Variable | `RESET` | Undocumented
Instance Variable | `spinner` | Undocumented
Instance Variable | `spinner_visible` | --== SEP_LINE ==--
Instance Variable | `start_time` | Undocumented
Instance Variable | `style` | Undocumented
Instance Variable | `style_len` | --== set default ==--
Instance Variable | `thread` | --== SEP_LINE ==--
Instance Variable | `time_color` | Undocumented
Instance Variable | `TIME_COLOR` | Undocumented
Instance Variable | `TXT_COLOR` | Undocumented
Instance Variable | `_screen_lock` | Undocumented

def __enter__(self):

Undocumented

def __exit__(self, exc_type, exc_val, exc_traceback):

Undocumented

def __init__(self, message='', *args, delay=0.2, style='pipe', **kwargs):

--== debugging ==--

def spin_backover(self, cleanup=False):

Undocumented

def spin_proc(self):

Undocumented

def write_next(self):

Undocumented

busy: `bool` =

Undocumented

centered =

Undocumented

chr_cnt: `int` =

Undocumented

clr_cnt: `int` =

Undocumented

color =

Undocumented

COLOR =

Undocumented

colors =

--== SEP_LINE ==--

delay =

Undocumented

elapsed =

Undocumented

etime =

Undocumented

prog: `bool` =

Undocumented

RESET =

Undocumented

spinner =

Undocumented

spinner_visible: `bool` =

--== SEP_LINE ==--

start_time =

Undocumented

style =

Undocumented

style_len: `int` =

--== set default ==--

thread =

--== SEP_LINE ==--

time_color =

Undocumented

TIME_COLOR =

Undocumented

TXT_COLOR =

Undocumented

_screen_lock =

Undocumented